netapp_ontap.models.storage_unit_maps API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.storage_unit_maps`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class StorageUnitMapsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the StorageUnitMaps object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `host_group: StorageUnitMapsHostGroup GET POST PATCH`

    A host group mapped to the storage unit. A host group is either an initiator group or an NVMe subsystem.

  `lun_map: StorageUnitMapsLunMap GET POST PATCH`

    A map between the storage unit and an initiator group.

  `subsystem_map: StorageUnitMapsSubsystemMap GET POST PATCH`

    A map between the storage unit and an NVMe subsystem.